const mongodb = require('mongodb');

const { ObjectId } = mongodb;

function findByName(name) {
    return { name };
}

function findById(id) {
    return { _id: ObjectId(id) };
}

function findByAttributes(objConstraints, searchFields) {
    let findQuery = {};
    /**
     * recordsNumber, pageNumber, includeTotalRows
     * ordering: [field, order]
     * simpleFilter: ['', '']
     * filtersByValue:[{ field, operator, value}]
     */
    if (objConstraints && objConstraints.simpleFilter) {
        const textToFind = objConstraints.simpleFilter[0];
        const queryRestrictions = [];
        searchFields.forEach((searchField) => {
            const fieldQuery = {};
            fieldQuery[searchField] = { $regex: textToFind };
            queryRestrictions.push(fieldQuery);
        });
        findQuery = { $or: queryRestrictions };
    } else if (objConstraints && objConstraints.filtersByValue) {
        objConstraints.filtersByValue.forEach((fieldFilter) => {
            const { field, operator, value } = fieldFilter;
            if (searchFields.includes(field)) {
                if (operator === '==') {
                    findQuery[field] = value;
                }
            }
        });
    }
    return findQuery;
}

function updateObj(appData) {
    return [
        { $set: { ...appData } },
    ];
}

module.exports = {
    findByName,
    findById,
    updateObj,
    findByAttributes,
};