const Joi = require('joi');
const { dataConstraints, requestReference } = require('./common');

const getEnvironments = Joi.object().keys({
  data: Joi.object().keys({
    name: Joi.string().description('Nombre del entorno'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const createEnvironment = Joi.object().keys({
  data: Joi.object().keys({
    name: Joi.string().description('Nombre del entorno'),
    description: Joi.string().description('Descripción del propósito del entorno dentro del ecosistema'),
  }),
  _requestReference: requestReference,
});

const activateEnvironment = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno a activar'),
  }),
  _requestReference: requestReference,
});

const inactivateEnvironment = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno a inactivar'),
  }),
  _requestReference: requestReference,
});

const deleteEnvironment = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno a eliminar'),
  }),
  _requestReference: requestReference,
});

const getRoles = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno al que deben pertenecer los roles'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const createRole = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno al que debe pertenecer el rol'),
    name: Joi.string().description('Nombre del Rol a crear'),
    description: Joi.string().description('Descripción del Rol a crear'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const activateRole = Joi.object().keys({
  data: Joi.object().keys({
    roleId: Joi.string().description('Código del rol a activar'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const inactivateRole = Joi.object().keys({
  data: Joi.object().keys({
    roleId: Joi.string().description('Código del rol a inactivar'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const deleteRole = Joi.object().keys({
  data: Joi.object().keys({
    roleId: Joi.string().description('Código del rol a eliminar'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const getRoleRelations = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno al que deben pertenecer los roles'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const createRoleRelation = Joi.object().keys({
  data: Joi.object().keys({
    environmentId: Joi.string().description('Código del entorno al que deben pertenecer los roles'),
    primaryRoleId: Joi.string().description('Código del rol primario'),
    primaryRoleName: Joi.string().description('Nombre del rol en la relación'),
    secondaryRoleId: Joi.string().description('Código del rol secundario'),
    secondaryRoleName: Joi.string().description('Nombre del rol secundario en la relación'),
    description: Joi.string().description('Descripción de la relación'),
    groupBased: Joi.boolean().description('Identificador boolean de que el tipo de relación es basada en grupos de terceros'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const modifyRoleRelation = Joi.object().keys({
  data: Joi.object().keys({
    roleRelationId: Joi.string().description('Código de la relación entre roles'),
    primaryRoleName: Joi.string().description('Nombre del rol en la relación'),
    secondaryRoleName: Joi.string().description('Nombre del rol secundario en la relación'),
    description: Joi.string().description('Descripción de la relación'),
    groupBased: Joi.string().description('Identificador boolean de que el tipo de relación es basada en grupos de terceros'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const activateRoleRelation = Joi.object().keys({
  data: Joi.object().keys({
    roleRelationId: Joi.string().description('Código del tipo de relación a activar'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const inactivateRoleRelation = Joi.object().keys({
  data: Joi.object().keys({
    roleRelationId: Joi.string().description('Código del tipo de relación a inactivar'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const deleteRoleRelation = Joi.object().keys({
  data: Joi.object().keys({
    roleRelationId: Joi.string().description('Código del tipo de relación a eliminar'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const schemas = {
  getEnvironments,
  createEnvironment,
  activateEnvironment,
  inactivateEnvironment,
  deleteEnvironment,
  getRoles,
  createRole,
  activateRole,
  inactivateRole,
  deleteRole,
  getRoleRelations,
  createRoleRelation,
  modifyRoleRelation,
  activateRoleRelation,
  inactivateRoleRelation,
  deleteRoleRelation,
};

module.exports = schemas;
