const Joi = require('joi');
const { dataConstraints, requestReference } = require('./common');

const createProductPriceType = Joi.object().keys({
  data: Joi.object().keys({
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
    name: Joi.string().description('Nombre de la tarifa'),
    description: Joi.string().description('Descripción o detalle de la tarifa'),
    roleRelationId: Joi.string().description('Relación de roles requerida para el grupo a asignar la tarifa'),
    minValue: Joi.string().description('Valor mínimo que puede tener la tarifa'),
    maxValue: Joi.string().description('Valor máximo que puede tener la tarifa'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const updateProductPriceType = Joi.object().keys({
  data: Joi.object().keys({
    productPriceTypeId: Joi.string().description('Código de identificación del tipo de tarifa creado'),
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
    name: Joi.string().description('Nombre de la tarifa'),
    description: Joi.string().description('Descripción o detalle de la tarifa'),
    roleRelationId: Joi.string().description('Relación de roles requerida para el grupo a asignar la tarifa'),
    minValue: Joi.string().description('Valor mínimo que puede tener la tarifa'),
    maxValue: Joi.string().description('Valor máximo que puede tener la tarifa'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const activateProductPriceType = Joi.object().keys({
  data: Joi.object().keys({
    productPriceTypeId: Joi.string().description('Código de identificación del tipo de tarifa'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const inactivateProductPriceType = Joi.object().keys({
  data: Joi.object().keys({
    productPriceTypeId: Joi.string().description('Código de identificación del tipo de tarifa'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const deleteProductPriceType = Joi.object().keys({
  data: Joi.object().keys({
    productPriceTypeId: Joi.string().description('Código de identificación del tipo de tarifa'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const defineGroupProductPrice = Joi.object().keys({
  data: Joi.object().keys({
    productPriceTypeId: Joi.string().description('Código de identificación del Tipo de tarifa'),
    productId: Joi.string().description('Código de identificación del producto'),
    subproductId: Joi.string().description('Opcional. Código de identificación del subproducto'),
    groupId: Joi.string().description('Código de identificación del grupo de terceros'),
    priceValue: Joi.string().description('Valor de la tarifa'),
    author: Joi.string().description('Código del usuario autor de la asignación'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const updateGroupProductPrice = Joi.object().keys({
  data: Joi.object().keys({
    gropuProductPrice: Joi.string().description('Código de identificación de la tarifa para el grupo'),
    productPriceTypeId: Joi.string().description('Código de identificación del Tipo de tarifa'),
    productId: Joi.string().description('Código de identificación del producto'),
    subproductId: Joi.string().description('Opcional. Código de identificación del subproducto'),
    groupId: Joi.string().description('Código de identificación del grupo de terceros'),
    priceValue: Joi.string().description('Valor de la tarifa'),
    author: Joi.string().description('Código del usuario autor de la asignación'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const activateGroupProductPrice = Joi.object().keys({
  data: Joi.object().keys({
    gropuProductPrice: Joi.string().description('Código de identificación de la tarifa para el grupo'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const inctivateGroupProductPrice = Joi.object().keys({
  data: Joi.object().keys({
    gropuProductPrice: Joi.string().description('Código de identificación de la tarifa para el grupo'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const deleteGroupProductPrice = Joi.object().keys({
  data: Joi.object().keys({
    gropuProductPrice: Joi.string().description('Código de identificación de la tarifa para el grupo'),
  }),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const schemas = {
  createProductPriceType,
  updateProductPriceType,
  activateProductPriceType,
  inactivateProductPriceType,
  deleteProductPriceType,
  defineGroupProductPrice,
  updateGroupProductPrice,
  activateGroupProductPrice,
  inctivateGroupProductPrice,
  deleteGroupProductPrice,
};

module.exports = schemas;
