const Joi = require('joi');
const { dataConstraints, requestReference } = require('./common');

const getProcessors = Joi.object().keys({
  data: Joi.object(),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const createProductProccessor = Joi.object().keys({
  data: Joi.object().keys({
    name: Joi.string().description('Nombre del gestor de producto'),
    fullname: Joi.string().description('Nombre completo del gestor del producto'),
    externalCode: Joi.string().description('Código externo del gestor para los sistemas de procesamiento de transacciones'),
    id: Joi.string().description('Código de identificación para la conexión con el gestor de producto'),
    secret: Joi.string().description('Clave, contraseña o token de identificación para la conexión con el gestor de producto'),
  }),
  _requestReference: requestReference,
});

const updateProductProccessor = Joi.object().keys({
  data: Joi.object().keys({
    productProcesorId: Joi.string().description('Código de identificación del procesador'),
    name: Joi.string().description('Nombre del gestor de producto'),
    fullname: Joi.string().description('Nombre completo del gestor del producto'),
    externalCode: Joi.string().description('Código externo del gestor para los sistemas de procesamiento de transacciones'),
    id: Joi.string().description('Código de identificación para la conexión con el gestor de producto'),
    secret: Joi.string().description('Clave, contraseña o token de identificación para la conexión con el gestor de producto'),
  }),
  _requestReference: requestReference,
});

const activateProductProccessor = Joi.object().keys({
  data: Joi.object().keys({
    productProcesorId: Joi.string().description('Código de identificación del procesador'),
  }),
  _requestReference: requestReference,
});

const inactivateProductProccessor = Joi.object().keys({
  data: Joi.object().keys({
    productProcesorId: Joi.string().description('Código de identificación del procesador'),
  }),
  _requestReference: requestReference,
});

const createProductFamily = Joi.object().keys({
  data: Joi.object().keys({
    name: Joi.string().description('Nombre de la familia de productos'),
    description: Joi.string().description('Descripción de la familia de productos'),
    nature: Joi.string().description('Identificador de CashIn o CashOut para la familia de productos'),
  }),
  _requestReference: requestReference,
});

const updateProductFamily = Joi.object().keys({
  data: Joi.object().keys({
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
    name: Joi.string().description('Nombre de la familia de productos'),
    description: Joi.string().description('Descripción de la familia de productos'),
    nature: Joi.string().description('Identificador de CashIn o CashOut para la familia de productos'),
  }),
  _requestReference: requestReference,
});

const activateProductFamily = Joi.object().keys({
  data: Joi.object().keys({
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
  }),
  _requestReference: requestReference,
});

const inactivateProductFamily = Joi.object().keys({
  data: Joi.object().keys({
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
  }),
  _requestReference: requestReference,
});

const deleteProductFamily = Joi.object().keys({
  data: Joi.object().keys({
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
  }),
  _requestReference: requestReference,
});

const createProduct = Joi.object().keys({
  data: Joi.object().keys({
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
    name: Joi.string().description('Nombre del producto'),
    description: Joi.string().description('Descripción del producto'),
    proccessorId: Joi.string().description('Código de identificación del procesador o gestor del producto'),
    supportSubproducts: Joi.boolean().description('Identifica si el producto soporta subproductos'),
  }),
  _requestReference: requestReference,
});

const updateProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
    productFamilyId: Joi.string().description('Código de identificación de la familia de productos'),
    name: Joi.string().description('Nombre del producto'),
    description: Joi.string().description('Descripción del producto'),
    proccessorId: Joi.string().description('Código de identificación del procesador o gestor del producto'),
    supportSubproducts: Joi.boolean().description('Identifica si el producto soporta subproductos'),
  }),
  _requestReference: requestReference,
});

const activateProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
  }),
  _requestReference: requestReference,
});

const inactivateProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
  }),
  _requestReference: requestReference,
});

const deleteProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
  }),
  _requestReference: requestReference,
});

const createSubproduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
    name: Joi.string().description('Nombre del subproducto'),
    description: Joi.string().description('Descripción'),
    supportOwnPrice: Joi.boolean().description('Indicador boolean que determina si el subproducto puede tener su propia tarifa'),
  }),
  _requestReference: requestReference,
});

const updateSubproduct = Joi.object().keys({
  data: Joi.object().keys({
    subproductId: Joi.string().description('Código de identificación del subproducto'),
    productId: Joi.string().description('Código de identificación del producto'),
    name: Joi.string().description('Nombre del subproducto'),
    description: Joi.string().description('Descripción'),
    supportOwnPrice: Joi.boolean().description('Indicador boolean que determina si el subproducto puede tener su propia tarifa'),
  }),
  _requestReference: requestReference,
});

const activateSubproduct = Joi.object().keys({
  data: Joi.object().keys({
    subproductId: Joi.string().description('Código de identificación del subproducto'),
  }),
  _requestReference: requestReference,
});

const inactivateSubproduct = Joi.object().keys({
  data: Joi.object().keys({
    subproductId: Joi.string().description('Código de identificación del subproducto'),
  }),
  _requestReference: requestReference,
});

const deleteSubproduct = Joi.object().keys({
  data: Joi.object().keys({
    subproductId: Joi.string().description('Código de identificación del subproducto'),
  }),
  _requestReference: requestReference,
});

const enableGroupProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
    subproductId: Joi.string().description('OPCIONAL: Código de identificación del subproducto'),
    groupId: Joi.string().description('Código de Identificación del grupo'),
    author: Joi.string().description('Usuario que registra la tarifa para el producto'),
  }),
  _requestReference: requestReference,
});

const disableGroupProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
    subproductId: Joi.string().description('OPCIONAL: Código de identificación del subproducto'),
    groupId: Joi.string().description('Código de Identificación del grupo'),
    author: Joi.string().description('Usuario que registra la tarifa para el producto'),
  }),
  _requestReference: requestReference,
});

const enableThirdPartyProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
    subproductId: Joi.string().description('OPCIONAL: Código de identificación del subproducto'),
    thirdPartyId: Joi.string().description('Código de Identificación del tercero'),
    author: Joi.string().description('Usuario que registra la tarifa para el producto'),
  }),
  _requestReference: requestReference,
});

const disableThirdPartyProduct = Joi.object().keys({
  data: Joi.object().keys({
    productId: Joi.string().description('Código de identificación del producto'),
    subproductId: Joi.string().description('OPCIONAL: Código de identificación del subproducto'),
    thirdPartyId: Joi.string().description('Código de Identificación del tercero'),
    author: Joi.string().description('Usuario que registra la tarifa para el producto'),
  }),
  _requestReference: requestReference,
});

const schemas = {
  getProcessors,
  createProductProccessor,
  updateProductProccessor,
  activateProductProccessor,
  inactivateProductProccessor,
  createProductFamily,
  updateProductFamily,
  activateProductFamily,
  inactivateProductFamily,
  deleteProductFamily,
  createProduct,
  updateProduct,
  activateProduct,
  inactivateProduct,
  deleteProduct,
  createSubproduct,
  updateSubproduct,
  activateSubproduct,
  inactivateSubproduct,
  deleteSubproduct,
  enableGroupProduct,
  disableGroupProduct,
  enableThirdPartyProduct,
  disableThirdPartyProduct,
};

module.exports = schemas;
