const Joi = require('joi');
const { dataConstraints, requestReference } = require('./common');

const getThirdParties = Joi.object().keys({
  data: Joi.object(),
  _dataConstraints: dataConstraints,
  _requestReference: requestReference,
});

const getThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().allow(null).description('Tipo de documento de identificación'),
    idDocType: Joi.string().description('Tipo de documento de identificación'),
    idDocNumber: Joi.string().description('Número de documento de identificación'),
  }),
  _requestReference: requestReference,
});

const createThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    idDocType: Joi.string().description('Tipo de documento de identificación'),
    idDocNumber: Joi.string().description('Número de documento de identificación'),
    shortName: Joi.string().description('Nombre corto del tercero'),
    fullName: Joi.string().description('Nombre completo'),
    country: Joi.string().description('Código ISO del pais'),
    city: Joi.string().description('Código de la ciudad'),
    postalCode: Joi.string().description('Código postal de la ubicación del tercero'),
    address: Joi.string().description('Dirección de la ubicación del tercero'),
    latitude: Joi.string().description('Latitud de la ubicación del tercero'),
    longitude: Joi.string().description('Longitud de la ubicación del tercero'),
  }),
  _requestReference: requestReference,
});

const addExternalRefThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
    externalSource: Joi.string().description('Código de identificación de la fuente externa o sistema'),
    externalCode: Joi.string().description('Código de identificación del tercero para dicha fuente externa'),
  }),
  _requestReference: requestReference,
});

const ativateThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
  }),
  _requestReference: requestReference,
});

const inativateThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
  }),
  _requestReference: requestReference,
});

const deleteThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
  }),
  _requestReference: requestReference,
});

const addRoleThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
    roleId: Joi.string().description('Código del rol a asignar al tercero'),
  }),
  _requestReference: requestReference,
});

const activateRoleThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
    roleId: Joi.string().description('Código del rol a asignar al tercero'),
  }),
  _requestReference: requestReference,
});

const inactivateRoleThirdParty = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyId: Joi.string().description('Código interno de identificación del tercero'),
    roleId: Joi.string().description('Código del rol a asignar al tercero'),
  }),
  _requestReference: requestReference,
});

const createGroup = Joi.object().keys({
  data: Joi.object().keys({
    ownerId: Joi.string().description('Código interno de identificación del tercero dueño del grupo'),
    groupName: Joi.string().description('Nombre del grupo'),
    roleRelationId: Joi.string().description('Opcional. Código del tipo de relación requerido entre el propietario y sus miembros.'),
    exclusive: Joi.string().description('Opcional. Indicador de grupo exclusivo, de forma que los miembros no pueden pertenecer a ningún otro grupo con el mismo roleRelationId'),
  }),
  _requestReference: requestReference,
});

const activateGroup = Joi.object().keys({
  data: Joi.object().keys({
    groupId: Joi.string().description('Código de identificación del grupo a activar'),
  }),
  _requestReference: requestReference,
});

const inactivateGroup = Joi.object().keys({
  data: Joi.object().keys({
    groupId: Joi.string().description('Código de identificación del grupo'),
  }),
  _requestReference: requestReference,
});

const deleteGroup = Joi.object().keys({
  data: Joi.object().keys({
    groupId: Joi.string().description('Código de identificación del grupo'),
  }),
  _requestReference: requestReference,
});

const addThirdPartyToGroup = Joi.object().keys({
  data: Joi.object().keys({
    groupId: Joi.string().description('Código de identificación del grupo'),
    thirdPartyId: Joi.string().description('Código de identificación del tercero'),
    author: Joi.string().description('Código del usuario que realizó la adición'),
  }),
  _requestReference: requestReference,
});

const deleteThirdPartyFromGroup = Joi.object().keys({
  data: Joi.object().keys({
    groupId: Joi.string().description('Código de identificación del grupo'),
    thirdPartyId: Joi.string().description('Código de identificación del tercero'),
    author: Joi.string().description('Código del usuario que realizó la eliminación'),
  }),
  _requestReference: requestReference,
});

const moveGroupMembers = Joi.object().keys({
  data: Joi.object().keys({
    sourceGroupId: Joi.string().description('Código de identificación del grupo origen'),
    destinationGroupId: Joi.string().description('Código de identificación del grupo destino'),
    author: Joi.string().description('Código del usuario que realizó el traslado'),
  }),
  _requestReference: requestReference,
});

const relateThirdParties = Joi.object().keys({
  data: Joi.object().keys({
    primaryThirdParty: Joi.string().description('Código del tercero primario en la relación'),
    secondaryThirdParty: Joi.string().description('Código del tercero secundario en la relación'),
    roleRelationId: Joi.string().description('Tipo de relación que se establece entre los terceros'),
  }),
  _requestReference: requestReference,
});

const deleteThirdPartiesRelation = Joi.object().keys({
  data: Joi.object().keys({
    thirdPartyRelationId: Joi.string().description('Id de la relación entre terceros'),
  }),
  _requestReference: requestReference,
});

const unrelateThirdParties = Joi.object().keys({
  data: Joi.object().keys({
    primaryThirdParty: Joi.string().description('Código del tercero primario en la relación'),
    secondaryThirdParty: Joi.string().description('Código del tercero secundario en la relación'),
    roleRelationId: Joi.string().description('Tipo de relación que se establece entre los terceros'),
  }),
  _requestReference: requestReference,
});

const schemas = {
  getThirdParties,
  getThirdParty,
  createThirdParty,
  addExternalRefThirdParty,
  ativateThirdParty,
  inativateThirdParty,
  deleteThirdParty,
  addRoleThirdParty,
  activateRoleThirdParty,
  inactivateRoleThirdParty,
  createGroup,
  activateGroup,
  inactivateGroup,
  deleteGroup,
  addThirdPartyToGroup,
  deleteThirdPartyFromGroup,
  moveGroupMembers,
  relateThirdParties,
  deleteThirdPartiesRelation,
  unrelateThirdParties,
};

module.exports = schemas;
