const EnvironmentManager = require('./lib/ecosystem/environment');
const PriceManager = require('./lib/ecosystem/prices');
const ProductManager = require('./lib/ecosystem/products');
const ThirdPartyManager = require('./lib/ecosystem/third-parties');
const {
  dbQueries: {
    environment: envQueries,
    prices: priceQueries,
    products: productQueries,
    thirdparties: thirdpartyQueries,
  },
} = require('./config');

const { openPoolSet, getDb } = require('./lib/helpers/db-pool');

class EcosystemManager {
  constructor(databaseParams, logger, errMgr) {
    this.logger = logger;
    this.errMgr = errMgr;
    this.initObjects(databaseParams, logger, errMgr);
  }

  async initObjects(databaseParams, logger, errMgr) {
    await openPoolSet(databaseParams, logger, errMgr);
    this.environmentManager = new EnvironmentManager(getDb, logger, errMgr, envQueries);
    this.priceManager = new PriceManager(getDb, logger, errMgr, priceQueries);
    this.productManager = new ProductManager(getDb, logger, errMgr, productQueries);
    this.thirdPartyManager = new ThirdPartyManager(logger, errMgr, thirdpartyQueries);
  }
}

module.exports = EcosystemManager;
